@@ -1,7 +1,9 @@
 pub mod init;
 pub mod increment_usages;
 pub mod invalidate;
+pub mod close;
 
 pub use init::*;
 pub use increment_usages::*;
 pub use invalidate::*;
+pub use close::*;
